// uncomment to get the various version
// the default with CGAL-3.9 is
// visibility walk with structural filtering with no no equilibrate turn
// in CGAL-3.10, equilibrate turn will be used

// STRAIGHT WALK
//#define CGAL_NO_STRUCTURAL_FILTERING
//#define CGAL_LFC_WALK

// VISIBILITY WALK certifying predicates all along the walk
//#define CGAL_NO_STRUCTURAL_FILTERING

// VISIBILITY WALK with structural filtering and with some balance between right and left turns
#define CGAL_EQUILIBRATE_TURN_SF_ONLY

#include <iostream>
#include <CGAL/Exact_predicates_inexact_constructions_kernel.h>
#include <CGAL/Delaunay_triangulation_2.h>
#include <CGAL/point_generators_2.h>
#include <CGAL/iterator.h>
#include <CGAL/Timer.h>

// choose the kernel
//typedef CGAL::Simple_cartesian<double> K;
typedef CGAL::Exact_predicates_inexact_constructions_kernel K;


typedef CGAL::Delaunay_triangulation_2<K>                   DT;
typedef CGAL::Random_points_in_square_2<DT::Point>          Rnd_points_it;
typedef CGAL::Counting_iterator<Rnd_points_it, DT::Point>   Points_iterator;

int main (int argc, char **argv)
{   int N = 10000; if( argc > 1 )N = atoi(argv[1]); // number of points
    Rnd_points_it   rand_it( 1.0);
    Points_iterator begin(rand_it), end(rand_it,1000000);
    DT dt;
    std::cout << " Walking in a Delaunay triangulation of "<< std::flush;
    dt.insert(begin,end);
    std::cout << "1000000 points in dim 2"<<std::endl<<N<<" locate"<< std::flush;
    CGAL::Timer cost; cost.reset();cost.start();
    for(int i=0 ; i<N; ++i) dt.locate(*++rand_it);
    std::cout << " done in "<<cost.time()/N*1000000<<" micro-seconds per point." << std::endl;
    return 0;
}
